# videojs-skip-intro

Shows a button during recaps, intros etc to allow the viewer to skip that part of the content. Video Cloud cue points set the in/out points, or at least the out points.

By default the plugin looks for `CODE` cue points with the names `start_recap`, `end_recap`, `start_intro`, and `end_intro`.

If an `end_*` cue is found with no corresponding `start_*`, a start cue is inserted after the preceding cue, or at the beginning of the video if there is no preceding cue.

If a `start_*` cue is found without a corresponding `end_*`, it is ignored.

If other cue names are to be used, ranges can be set in the plugin options:

```js
player.skipIntro({
  ranges: [
    {
      name: 'boring_bit',
      label: 'Yeah just jump past this bit'
    }
  ]
});
```

The plugin would then look for `start_boring_bit` and `end_boring_bit` cues. The value of label is the button text.

## Installation

```sh
npm install --save @videojs-skip-intro/videojs-skip-intro
```

## Usage

To include videojs-skip-intro on your website or web application, use any of the following methods.

### `<script>` Tag

This is the simplest case. Get the script in whatever way you prefer and include the plugin _after_ you include [video.js][videojs], so that the `videojs` global is available.

```html
<script src="//path/to/video.min.js"></script>
<script src="//path/to/videojs-skip-intro.min.js"></script>
<script>
  var player = videojs('my-video');

  player.skipIntro();
</script>
```

### Browserify/CommonJS

When using with Browserify, install videojs-skip-intro via npm and `require` the plugin as you would any other module.

```js
var videojs = require('video.js');

// The actual plugin function is exported by this module, but it is also
// attached to the `Player.prototype`; so, there is no need to assign it
// to a variable.
require('@videojs-skip-intro/videojs-skip-intro');

var player = videojs('my-video');

player.skipIntro();
```

### RequireJS/AMD

When using with RequireJS (or another AMD library), get the script in whatever way you prefer and `require` the plugin as you normally would:

```js
require(['video.js', '@videojs-skip-intro/videojs-skip-intro'], function(videojs) {
  var player = videojs('my-video');

  player.skipIntro();
});
```

## License

MIT. Copyright (c) mister-ben &lt;git@misterben.me&gt;


[videojs]: http://videojs.com/
