import document from 'global/document';

import QUnit from 'qunit';
import sinon from 'sinon';
import videojs from 'video.js';

import plugin from '../src/plugin';

const Player = videojs.getComponent('Player');

QUnit.test('the environment is sane', function(assert) {
  assert.strictEqual(typeof Array.isArray, 'function', 'es5 exists');
  assert.strictEqual(typeof sinon, 'object', 'sinon exists');
  assert.strictEqual(typeof videojs, 'function', 'videojs exists');
  assert.strictEqual(typeof plugin, 'function', 'plugin is a function');
});

QUnit.module('videojs-skip-intro', {

  beforeEach() {

    // Mock the environment's timers because certain things - particularly
    // player readiness - are asynchronous in video.js 5. This MUST come
    // before any player is created; otherwise, timers could get created
    // with the actual timer methods!
    this.clock = sinon.useFakeTimers();

    this.fixture = document.getElementById('qunit-fixture');
    this.video = document.createElement('video');
    this.fixture.appendChild(this.video);
    this.player = videojs(this.video);

    const track = this.player.addTextTrack('metadata');

    track.mode = 'hidden';

    this.player.mediaCuePointsTrack = () => track;
  },

  afterEach() {
    this.player.dispose();
    this.clock.restore();
  }
});

QUnit.test('registers itself with video.js', function(assert) {
  assert.expect(3);

  assert.strictEqual(
    typeof Player.prototype.skipIntro,
    'function',
    'videojs-skip-intro plugin was registered'
  );

  this.player.skipIntro();

  // Tick the clock forward enough to trigger the player to be "ready".
  this.clock.tick(1);

  assert.ok(
    this.player.hasClass('vjs-skip-intro'),
    'the plugin adds a class to the player'
  );

  assert.ok(
    this.player.skipIntroButton,
    'the button is added to the player'
  );
});

/* need to populate mediainfo and add cues */

// QUnit.test('shows button', function(assert) {
//   this.player.mediainfo = {
//     cuePoints: {

//     }
//   }
//   this.player.mediaCuePointsTrack().addCue(
//     new VTTCue(0.1, 5, 'skip_intro')
//   );
//   this.player.mediaCuePointsTrack().addCue(
//     new VTTCue(5.1, 10, 'skip_intro')
//   );
//   this.player.skipIntro();
//   this.clock.tick(1);
//   this.player.trigger('loadedmetadata');
//   this.player.tech_.currentTime = () => 2;
//   this.player.trigger('timeupdate');
//   assert.ok(
//     !this.player.skipIntroButton.hasClass('vjs-hidden'),
//     'the button is shown'
//   )
// });
